@@ -11,7 +11,8 @@ class Mailable:
                  from_name: Optional[str] = None,
                  reply_to: Optional[str] = None,
                  plain: str = None,
-                 html: str = None):
+                 html: str = None,
+                 attachments: list = None):
         self.subject = subject
         self.to_addr = to_addr
         self.from_addr = from_addr
@@ -21,3 +22,4 @@ class Mailable:
         self.reply_to = reply_to
         self.plain = plain
         self.html = html
+        self.attachments = attachments
