@@ -40,11 +40,28 @@ class SmtpTransport(Transport):
         if mailable.bcc is not None:
             msg['bcc'] = list(mailable.bcc)
             to_addrs += list(mailable.bcc)
-
-        if mailable.html:
-            msg.set_content(mailable.html, subtype='html')
+        has_attachment = False
+        if mailable.attachments is not None:
+            for attachment in mailable.attachments:
+                has_attachment = True
+                content = attachment['content']
+                filename = attachment['filename']
+                attachment_kwarg = {}
+                for (k, v) in attachment.items():
+                    if k == 'content' or k == 'filename':
+                        continue
+                    attachment_kwarg[k] = v
+                msg.add_attachment(content, filename=filename, **attachment_kwarg)
+        if not has_attachment:
+            if mailable.html:
+                msg.set_content(mailable.html, subtype='html')
+            elif mailable.plain:
+                msg.set_content(mailable.plain)
         else:
-            msg.set_content(mailable.plain)
+            if mailable.html:
+                msg._add_multipart('mixed', mailable.html, subtype='html')
+            elif mailable.plain:
+                msg._add_multipart('mixed', mailable.plain, subtype='plain')
         smtp.sendmail(from_addr=from_addr,
                       to_addrs=to_addrs,
                       msg=msg.as_string())
