@@ -19,14 +19,13 @@ class SlackClient(NotificationChannel):
         channel = msg.channel or self.default_channel
         payload = {}
 
-        if msg.has_blocks():
+        if msg.has_blocks:
             payload['blocks'] = msg.blocks
             if msg.has_mentions:
                 payload['blocks'] = msg.with_mentions(msg.blocks)
-        else:
-            payload['text'] = msg.text
-            if msg.has_mentions:
-                payload['text'] = msg.with_mentions(msg.text)
+        payload['text'] = msg.text
+        if msg.has_mentions:
+            payload['text'] = msg.with_mentions(msg.text)
 
         if msg.has_link:
             payload['link_names'] = 1
