@@ -15,14 +15,16 @@ class SlackMessage:
         self.mentions = mentions
 
         self.channel = channel
-        if self.has_mentions():
+        if self.has_mentions:
             self.has_link = True
-        if self.has_blocks():
+        if self.text is None:
             self.text = ''
 
+    @property
     def has_mentions(self) -> bool:
         return self.mentions is not None and len(self.mentions) > 0
 
+    @property
     def has_blocks(self):
         return self.blocks is not None and len(self.blocks) > 0
 
@@ -31,7 +33,7 @@ class SlackMessage:
         if isinstance(message_data, str):
             return '{} {}'.format(mentions, message_data)
         if isinstance(message_data, list):
-            return [{'type': 'section', 'text': {"type": "plain_text", "text": mentions}}] + message_data
+            return [{'type': 'section', 'text': {"type": "mrkdwn", "text": mentions}}] + message_data
         return message_data
 
     def _mention_text(self):
