@@ -46,9 +46,14 @@ try:
         def email_subject(self) -> str:
             raise NotImplementedError()
 
+        @property
+        def attachments(self) -> Optional[list]:
+            return None
+
         def to_mail(self):
             return Mailable(to_addr=self.email_to_addr,
                             subject=self.email_subject,
+                            attachments=self.attachments,
                             html=render(self.email_template, self.email_template_file, self.email_variables))
 except ImportError:
     pass
